<TS language="af_ZA" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Regs-klik om die adres of etiket te wysig</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Skep 'n nuwe adres</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuwe</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Maak 'n kopie van die huidige adres na die stelsel klipbord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopie</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>S&amp;luit</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Verwyder die uitgekiesde adres van die lys</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Voer inligting uit van die huidige blad na n lêer</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Uitvoer</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwyder</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Kies die address na wie die muntstukke gestuur moet word</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Kies die adres vir die ontvangs van betaaling</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>K&amp;ies</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Stuur adresse</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Ontvang adresse</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Dit is jou Litecoin-adresse vir die stuur van betalings. Kontroleer altyd die bedrag en die ontvangsadres voordat u munte stuur.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Dit is jou Litecoin-adresse vir die stuur van betalings. Kontroleer altyd die bedrag en die ontvangsadres voordat jy munte stuur.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopie Adres</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopie &amp;Etiket</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Wysig</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Voer adres lys uit</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Koma geskeide lêer (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Uitvoering Misluk</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Kon nie die adreslys stoor na %1 nie. Probeer asseblief weer.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wagfrase Dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Tik wagfrase in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuwe wagfrase</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nuwe wagfrase</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Wys wagwoord</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Tik die nuwe wagwoord vir die beursie in.&lt;br/&gt;Gebruik asseblief 'n wagwoord van &lt;b&gt;ten minste 10 ewekansige karakters&lt;/b&gt;, of &lt;b&gt;agt (8) of meer woorde.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Enkripteer beursie</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Hierdie operasie benodig 'n wagwoord om die beursie oop te sluit.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ontsluit beursie</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Hierdie operasie benodig 'n wagwoord om die beursie oop te sluit.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dekripteer beursie</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Verander wagfrase</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Tik in die ou wagfrase en die nuwe wagfrase vir die beursie.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig beursie enkripsie.</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Waarskuwing: As jy jou beursie enkripteer en jou wagwoord verloor, sal jy &lt;b&gt;AL JOU LITECOINS VERLOOR&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Is jy seker jy wil jou beursie enkripteer?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Beursie enkriptasie voltooi</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>BELANGRIK: Enige vorige rugsteune wat u gemaak het van u beursie-lêer moet vervang word met die nuut-gegenereerde, versleutelde beursie-lêer. Vir sekuriteitsredes sal vorige rugsteune van die onversleutelde beursie-lêer onbruikbaar word sodra u die nuwe, versleutelde beursie begin gebruik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Beursie enkriptasie het misluk</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Beursie bewaaking het misluk as gevolg van 'n interne fout. Die beursie is nie bewaak nie!</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Die wagfrase stem nie ooreen nie</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Beursie oopsluiting het misluk</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Die wagfrase wat ingetik was om die beursie oop te sluit, was verkeerd.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Beursie dekripsie het misluk</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Die beursie se wagfrase verandering was suksesvol.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Waarskuwing: Die Caps Lock is aan!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmasker</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Verban Tot</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinchroniseer met die netwerk ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oorsig</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Wys algemene oorsig van die beursie</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksies</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Besoek transaksie geskiedenis</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;luit af</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sluit af</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Oor %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Wys inligting oor %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Oor &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Wys inligting oor Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsies</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Verander konfigurasie opsies vir %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkripteer Beursie...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Rugsteun Beursie...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Verander wagwoord frase...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Maak &amp;URI oop...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Klik om netwerk aktiwiteit af te skakel.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Netwerk aktiwiteid afgeskakel.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Klik om netwerk aktiwiteit weer aan te skakel.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Sinkroniseer tans Hoofde (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Herindekseer blokke op skyf...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Stuur muntstukke na 'n Litecoin adres</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Rugsteun beursie na 'n ander plek</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Verander die wagwoordfrase wat vir beursie-versleuteling gebruik word</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Ontfoutvenster</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Open ontfouting en diagnostiese konsole</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifieer boodskap...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Stuur</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ontvang</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Wys / Versteek</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Wys of versteek die hoof Venster</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Versleutel die private sleutels wat aan u beursie behoort</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Teken boodskappe met u Litecoin adresse om te bewys dat u hul besit</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Bevestig boodskappe om te verseker dat hulle geteken was met gespesifiseerde Litecoin adresse</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Lêer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Blad nutsbalk</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Versoek betalings (genereer QR kodes en litecoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Wys die lys van gebruikte stuur adresse en etikette</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Wys die lys van gebruikte ontvangsadresse en etikette</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Open 'n litecoin: URI of betalingsversoek</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Opdrag lys opsies</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indekseer tans blokke op skyf...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Prosesseer tans blokke op skyf...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 agter</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ontvangs van laaste blok is %1 terug.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transaksies hierna sal nog nie sigbaar wees nie.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarskuwing</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Op datum</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Wys die %1 hulpboodskap om 'n lys met moontlike Litecoin bevel-lyn opsies te verkry</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klient</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Verbind tans aan eweknieë...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Besig om op te vang...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Bedrag: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tipe: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etiket: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adres: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaksie gestuur</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Inkomende transaksie</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD sleutel generasie is &lt;b&gt;aangesit&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD sleutel generasie is &lt;b&gt;afgesit&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Beursie is &lt;b&gt;versleutel&lt;/b&gt; en is tans &lt;b&gt;oopgesluit&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Beursie is &lt;b&gt;versleutel&lt;/b&gt; en is tans &lt;b&gt;gesluit&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>'n Noodlottige fout het voorgekom. Litecoin kan nie langer voortgaan nie en sal afsluit.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Munt Keuse</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Grepe:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Stof:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Verander:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(on)selekteer alles</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Boom wyse</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Lys wyse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ontvang met etiket</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ontvang met adres</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bevestigings</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>Sluit ongespandeerde</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>Onsluit ongespandeerde</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer grepe</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer stof</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 gesluit)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Hierdie etiket verander na rooi as enige ontvanger 'n bedrag kleiner as die huidige stof drempelwaarde ontvang.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Kan wissel met +/- %1 satoshi(s) per inset.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>Verander vanaf %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(verander)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Wysig Adres</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiket</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Die etiket geassosieer met hierdie adreslys inskrywing</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Die adres geassosieer met hierdie adreslys inskrywing. Dié kan slegs gewysig word vir stuur-adresse.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adres</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuwe stuurende adres</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Wysig ontvangende adres</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Wysig stuurende adres</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>Die ingeskrewe adres "%1" is nie 'n geldige Litecoin adres nie.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kon nie die beursie oopsluit nie.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Nuwe sleutel genereering het misluk.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>n Nuwe data  lêer sal geskep word.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>naam</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Lêer bestaan reeds. Voeg %1 indien u van plan is om n nuwe lêer hier te skep.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Pad bestaan reeds en is nie 'n lêergids nie.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Kan nie data gids hier skep nie.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>weergawe</translation>
    </message>
    <message>
        <source>(%1-bit)</source>
        <translation>(%1-stukkie)</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Oor %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opdrag lys opsies</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Welkom</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Welkom by %1.</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Die beursie sal ook gestoor word in hierdie lêer.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Vorderering</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Steek weg</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsies</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Netwerk</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>&amp;Beursie</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>V&amp;erminder op toemaak</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Vertoon</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Kanselleer</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standaard</translation>
    </message>
    <message>
        <source>none</source>
        <translation>niks</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Konfigurasie opsies</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Beskikbaar:</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Balans</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 d</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 h</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 m</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 ms</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Informasie</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Bedrag:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Boodskap:</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Beursie</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Grepe:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Verander:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Transaksie fooi:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Steek weg</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Stuur aan vele ontvangers op eens</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Stof:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Balans:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;tuur</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer grepe</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer stof</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 tot %2</translation>
    </message>
    <message>
        <source>or</source>
        <translation>of</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Bedrag:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Teken boodskap</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Handtekening</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Na</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>eie adres</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiket</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediet</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nie aanvaar nie</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debiet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Netto bedrag</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Transaksie ID</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transaksie</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>true</source>
        <translation>waar</translation>
    </message>
    <message>
        <source>false</source>
        <translation>onwaar</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ontvang van</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betalings Aan/na jouself</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n.v.t)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum en tyd wat die transaksie ontvang was.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipe transaksie.</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Hierdie week</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hierdie maand</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Verlede maand</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Hierdie jaar</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Reeks...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Aan/na jouself</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ander</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min bedrag</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Koma geskeide lêer (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Uitvoering Misluk</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Reeks:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>aan</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Uitvoer</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Voer inligting uit van die huidige blad na n lêer</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Fout: Hardeskyf spasie is baie laag!</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Invoer proses tans besig..</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarskuwing</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Laai blok indeks...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Laai beursie...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar gelaai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>